@@ -116,8 +116,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -137,9 +137,9 @@ class LambdaToElasticSearchAndKibana(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        domain_name: str,
+        domain_name: builtins.str,
         es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -168,37 +168,37 @@ class LambdaToElasticSearchAndKibana(
 
         jsii.create(LambdaToElasticSearchAndKibana, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
         return jsii.get(self, "cloudwatchAlarms")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="elasticsearchDomain")
     def elasticsearch_domain(self) -> aws_cdk.aws_elasticsearch.CfnDomain:
         return jsii.get(self, "elasticsearchDomain")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="elasticsearchRole")
     def elasticsearch_role(self) -> aws_cdk.aws_iam.Role:
         return jsii.get(self, "elasticsearchRole")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="identityPool")
     def identity_pool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
         return jsii.get(self, "identityPool")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userPool")
     def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
         return jsii.get(self, "userPool")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="userPoolClient")
     def user_pool_client(self) -> aws_cdk.aws_cognito.UserPoolClient:
         return jsii.get(self, "userPoolClient")
@@ -218,7 +218,7 @@ class LambdaToElasticSearchAndKibanaProps:
     def __init__(
         self,
         *,
-        domain_name: str,
+        domain_name: builtins.str,
         es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -236,7 +236,7 @@ class LambdaToElasticSearchAndKibanaProps:
             es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "domain_name": domain_name,
         }
         if es_domain_props is not None:
@@ -247,13 +247,15 @@ class LambdaToElasticSearchAndKibanaProps:
             self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
-    def domain_name(self) -> str:
+    def domain_name(self) -> builtins.str:
         """Cognito & ES Domain Name.
 
         default
         :default: - None
         """
-        return self._values.get("domain_name")
+        result = self._values.get("domain_name")
+        assert result is not None, "Required property 'domain_name' is missing"
+        return result
 
     @builtins.property
     def es_domain_props(
@@ -264,7 +266,8 @@ class LambdaToElasticSearchAndKibanaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("es_domain_props")
+        result = self._values.get("es_domain_props")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -273,7 +276,8 @@ class LambdaToElasticSearchAndKibanaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -284,12 +288,13 @@ class LambdaToElasticSearchAndKibanaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
